@@ -19,3 +19,17 @@
 #' @importFrom Rcpp sourceCpp
 #'
 "_PACKAGE"
+
+.onAttach <- function(libname, pkgname) {
+  if (requireNamespace("qs2", quietly = TRUE)) {
+    if (isFALSE(qs2:::check_TBB())) {
+      packageStartupMessage(
+        "qs2 detected without TBB support.\n",
+        "For best performance, reinstall with:\n",
+        "remotes::install_cran(\"qs2\", type = \"source\", ",
+        "configure.args = \"--with-TBB --with-simd=AVX2\", ",
+        "force = TRUE)"
+      )
+    }
+  }
+}
